"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseColor = exports.locateFiles = exports.isError = exports.loadSVG = void 0;
const path_1 = __importDefault(require("path"));
const cheerio_1 = __importDefault(require("cheerio"));
const debug_1 = __importDefault(require("debug"));
const expand_tilde_1 = __importDefault(require("expand-tilde"));
const fast_glob_1 = __importDefault(require("fast-glob"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const debug = (0, debug_1.default)('sqip');
const loadSVG = (svg) => {
    return cheerio_1.default.load(svg, {
        xmlMode: true
    });
};
exports.loadSVG = loadSVG;
function isError(error) {
    return error instanceof Error;
}
exports.isError = isError;
function locateFiles(input) {
    return __awaiter(this, void 0, void 0, function* () {
        const enhancedInput = (0, expand_tilde_1.default)(input);
        let globPattern = enhancedInput;
        try {
            const stat = yield fs_extra_1.default.lstat(enhancedInput);
            if (stat.isFile()) {
                debug(`input ${input} is a file. Skip file search.`);
                return [enhancedInput];
            }
            if (stat.isDirectory()) {
                debug(`input ${input} is a directory. Enhancing with * to match all files.`);
                globPattern = `${path_1.default.resolve(enhancedInput)}/*`;
            }
        }
        catch (err) {
            if (isError(err) && err instanceof TypeError) {
                if (err.code === 'ENOENT') {
                    throw err;
                }
            }
        }
        // Find all files matching the enhanced glob
        const files = yield (0, fast_glob_1.default)(globPattern, {
            onlyFiles: true,
            extglob: true,
            absolute: true
        });
        // Test if files are found
        if (!files.length) {
            throw new Error(`Unable to find any files via ${globPattern}. Make sure the file exists.

If you are using globbing patterns, the following features are supported:

https://github.com/micromatch/micromatch#matching-features`);
        }
        return files;
    });
}
exports.locateFiles = locateFiles;
function parseColor({ palette, color }) {
    var _a;
    // @todo test, fallback to or detect transparent as color (for bg)
    return ((_a = palette[color]) === null || _a === void 0 ? void 0 : _a.hex) || color;
}
exports.parseColor = parseColor;
//# sourceMappingURL=helpers.js.map